==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/PacketCaptureMachineScopeArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.PacketCaptureMachineScopeArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * A list of AzureVMSS instances which can be included or excluded to run packet capture. If both included and excluded are empty, then the packet capture will run on all instances of AzureVMSS.
 * @property exclude List of AzureVMSS instances which has to be excluded from the AzureVMSS from running packet capture.
 * @property include List of AzureVMSS instances to run packet capture on.
 */
public data class PacketCaptureMachineScopeArgs(
    public val exclude: Output<List<String>>? = null,
    public val include: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.PacketCaptureMachineScopeArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.PacketCaptureMachineScopeArgs =
        com.pulumi.azurenative.network.inputs.PacketCaptureMachineScopeArgs.builder()
            .exclude(exclude?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .include(include?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [PacketCaptureMachineScopeArgs].
 */
@PulumiTagMarker
public class PacketCaptureMachineScopeArgsBuilder internal constructor() {
    private var exclude: Output<List<String>>? = null

    private var include: Output<List<String>>? = null

    /**
     * @param value List of AzureVMSS instances which has to be excluded from the AzureVMSS from running packet capture.
     */
    @JvmName("bvmbeagsoobocsax")
    public suspend fun exclude(`value`: Output<List<String>>) {
        this.exclude = value
    }

    @JvmName("aipbrtoeknnvnlyg")
    public suspend fun exclude(vararg values: Output<String>) {
        this.exclude = Output.all(values.asList())
    }

    /**
     * @param values List of AzureVMSS instances which has to be excluded from the AzureVMSS from running packet capture.
     */
    @JvmName("nikxefafkkbfjtfi")
    public suspend fun exclude(values: List<Output<String>>) {
        this.exclude = Output.all(values)
    }

    /**
     * @param value List of AzureVMSS instances to run packet capture on.
     */
    @JvmName("nartrywelndsdqxb")
    public suspend fun include(`value`: Output<List<String>>) {
        this.include = value
    }

    @JvmName("cckeffpytivwsugj")
    public suspend fun include(vararg values: Output<String>) {
        this.include = Output.all(values.asList())
    }

    /**
     * @param values List of AzureVMSS instances to run packet capture on.
     */
    @JvmName("ooxghcjnllxjnmuu")
    public suspend fun include(values: List<Output<String>>) {
        this.include = Output.all(values)
    }

    /**
     * @param value List of AzureVMSS instances which has to be excluded from the AzureVMSS from running packet capture.
     */
    @JvmName("veobxtffowtkjvpa")
    public suspend fun exclude(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.exclude = mapped
    }

    /**
     * @param values List of AzureVMSS instances which has to be excluded from the AzureVMSS from running packet capture.
     */
    @JvmName("iotmulrjyicxicpu")
    public suspend fun exclude(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.exclude = mapped
    }

    /**
     * @param value List of AzureVMSS instances to run packet capture on.
     */
    @JvmName("fmdnxtnytqhqwnvh")
    public suspend fun include(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.include = mapped
    }

    /**
     * @param values List of AzureVMSS instances to run packet capture on.
     */
    @JvmName("clrsxamgudcndmdf")
    public suspend fun include(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.include = mapped
    }

    internal fun build(): PacketCaptureMachineScopeArgs = PacketCaptureMachineScopeArgs(
        exclude = exclude,
        include = include,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/PacketCaptureMachineScopeArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.PacketCaptureMachineScopeArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * A list of AzureVMSS instances which can be included or excluded to run packet capture. If both included and excluded are empty, then the packet capture will run on all instances of AzureVMSS.
 * @property exclude List of AzureVMSS instances which has to be excluded from the AzureVMSS from running packet capture.
 * @property include List of AzureVMSS instances to run packet capture on.
 */
public data class PacketCaptureMachineScopeArgs(
    public val exclude: Output<List<String>>? = null,
    public val include: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.PacketCaptureMachineScopeArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.PacketCaptureMachineScopeArgs =
        com.pulumi.azurenative.network.inputs.PacketCaptureMachineScopeArgs.builder()
            .exclude(exclude?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .include(include?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [PacketCaptureMachineScopeArgs].
 */
@PulumiTagMarker
public class PacketCaptureMachineScopeArgsBuilder internal constructor() {
    private var exclude: Output<List<String>>? = null

    private var include: Output<List<String>>? = null

    /**
     * @param value List of AzureVMSS instances which has to be excluded from the AzureVMSS from running packet capture.
     */
    @JvmName("matrqgmngikotbki")
    public suspend fun exclude(`value`: Output<List<String>>) {
        this.exclude = value
    }

    @JvmName("camqnpskmskvspym")
    public suspend fun exclude(vararg values: Output<String>) {
        this.exclude = Output.all(values.asList())
    }

    /**
     * @param values List of AzureVMSS instances which has to be excluded from the AzureVMSS from running packet capture.
     */
    @JvmName("pnssjuqxsabqthod")
    public suspend fun exclude(values: List<Output<String>>) {
        this.exclude = Output.all(values)
    }

    /**
     * @param value List of AzureVMSS instances to run packet capture on.
     */
    @JvmName("nhsehmduewhdsepg")
    public suspend fun include(`value`: Output<List<String>>) {
        this.include = value
    }

    @JvmName("poeytqttmtulrnnh")
    public suspend fun include(vararg values: Output<String>) {
        this.include = Output.all(values.asList())
    }

    /**
     * @param values List of AzureVMSS instances to run packet capture on.
     */
    @JvmName("nafgcwuxpcyhlqaf")
    public suspend fun include(values: List<Output<String>>) {
        this.include = Output.all(values)
    }

    /**
     * @param value List of AzureVMSS instances which has to be excluded from the AzureVMSS from running packet capture.
     */
    @JvmName("leavrvokdiatqpua")
    public suspend fun exclude(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.exclude = mapped
    }

    /**
     * @param values List of AzureVMSS instances which has to be excluded from the AzureVMSS from running packet capture.
     */
    @JvmName("ypbwqwbcycmnquak")
    public suspend fun exclude(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.exclude = mapped
    }

    /**
     * @param value List of AzureVMSS instances to run packet capture on.
     */
    @JvmName("rylbtlxfnfqphnlr")
    public suspend fun include(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.include = mapped
    }

    /**
     * @param values List of AzureVMSS instances to run packet capture on.
     */
    @JvmName("pscqjyddnrssbsxe")
    public suspend fun include(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.include = mapped
    }

    internal fun build(): PacketCaptureMachineScopeArgs = PacketCaptureMachineScopeArgs(
        exclude = exclude,
        include = include,
    )
}
